@@ -25,11 +25,13 @@ function(input, output, session) {
       return(NULL) # if no file was uploaded return NULL
 
     data <- fread(file = inFile$datapath, data.table = FALSE) # inFile[1] contains filepath
+    if (ncol(data) > 3)
+      data <- data[, 1:3]
 
     if (ncol(data) == 2) {
       data$error <- 0.0001
-      data$group <- "A"
-    } else if (ncol(data) == 3) {
+    }
+    if (ncol(data) == 3) {
       data$group <- "A"
     }
 
@@ -48,31 +50,7 @@ function(input, output, session) {
   })
 
   observeEvent(input$table_in_primary, {
-
-    # Workaround for rhandsontable issue #138
-    # https://github.com/jrowen/rhandsontable/issues/138
-    # See detailed explanation in abanico application
-    df_tmp <- input$table_in_primary
-    row_names <-  as.list(as.character(seq_len(length(df_tmp$data))))
-    df_tmp$params$rRowHeaders <- row_names
-    df_tmp$params$rowHeaders <- row_names
-    df_tmp$params$rDataDim <- as.list(c(length(row_names),
-                                        length(df_tmp$params$columns)))
-    if (df_tmp$changes$event == "afterRemoveRow")
-      df_tmp$changes$event <- "afterChange"
-
-    if (!is.null(hot_to_r(df_tmp))) {
-      if (nrow(hot_to_r(df_tmp)) > 0) {
-        tryCatch({
-          values$data <- hot_to_r(df_tmp)
-        }, error = function(e) {
-            values$error <- e
-            values$results <- NULL
-          })
-      }
-    }
-      values$data <- hot_to_r(df_tmp)
-
+    values$data <- RLumShiny:::rhandsontable_workaround(input$table_in_primary)
   })
 
   output$global_fit_ages <- renderUI({
@@ -116,7 +94,6 @@ function(input, output, session) {
                         min = min(data[ ,2]) - diff(range(data[ ,2])) / 2,
                         max = max(data[ ,2]) + diff(range(data[ ,2])) / 2,
                         value = range(pretty(data[ ,2])))
-
   })
 
   # update for log values
@@ -136,11 +113,8 @@ function(input, output, session) {
                         value = range(pretty(data[ ,1])))
   })
 
-
   observe({
-
     if (input$global_fit) {
-
       # split data frame to list
       if (!all(is.na(values$data$group))) {
         data <- values$data[complete.cases(values$data), ]
@@ -157,8 +131,8 @@ function(input, output, session) {
           data$group <- droplevels(data$group)
 
         # remove line feeds that might be copied from the clipboard
-        data$group <- gsub("\r", "", data$group[1])
-        data$group <- gsub("\n", "", data$group[1])
+        data$group <- gsub("\r", "", data$group)
+        data$group <- gsub("\n", "", data$group)
 
         data <- split(data, data$group)
         # remove any list element with data.frames with 0 rows
@@ -198,7 +172,7 @@ function(input, output, session) {
 
     # fitting line color
     if (input$line_col == "custom")
-      line_col <- input$jscol
+      line_col <- input$jscol2
     else if (input$line_col == "default")
       line_col <- NULL
     else
@@ -208,12 +182,12 @@ function(input, output, session) {
       data = values$data_used,
       age = age,
       weights = if (input$global_fit) FALSE else input$weights,
-      sigmaphi = if (input$override_sigmaphi) input$sigmaphi_base * 10^-(abs(input$sigmaphi_exp)) else NULL,
+      sigmaphi = if (input$override_sigmaphi) input$sigmaphi_base * 10^input$sigmaphi_exp else NULL,
       mu = mu,
       Ddot = if (input$doserate) input$ddot else NULL,
       D0  = if (input$doserate) input$d0 else NULL,
       verbose = FALSE,
-      pch = ifelse(input$pch == "custom", input$custompch, as.numeric(input$pch) - 1),
+      pch = ifelse(input$pch == "custom", input$custompch, as.numeric(input$pch)),
       bg = ifelse(input$color == "custom", input$jscol1, input$color),
       cex = input$cex,
       legend = input$legend,
@@ -238,8 +212,11 @@ function(input, output, session) {
 
   observe({
     # nested renderText({}) for code output on "R plot code" tab
-    code.output <- callModule(RLumShiny:::printCode, "printCode", n_input = 1,
-                              fun = paste0("fit_SurfaceExposure(data,"), args = values$args)
+    code.output <- callModule(RLumShiny:::printCode, "printCode",
+                              n_inputs = 1,
+                              list(name = "fit_SurfaceExposure",
+                                   arg1 = "data",
+                                   args = values$args))
 
     output$plotCode<- renderText({
       code.output
@@ -278,24 +255,34 @@ function(input, output, session) {
 
     values$error <- NULL
 
+    ## helper to format the output string
+    report <- function(label, value, error, override_value = TRUE) {
+      paste(
+          tags$b(paste0(label, ":")), paste(value, collapse = ", "),
+          if (override_value) tags$em("(fixed)") else paste("&plusmn;", error),
+          tags$br()
+      )
+    }
+
     if (!input$global_fit) {
       res <- as.data.frame(t(signif(unlist(get_RLum(values$results)), 3)))
 
-      HTML(paste0(
-        tags$b("Age (a): "), res$age, " &plusmn; ", res$age_error, tags$em(ifelse(input$override_age, "(fixed)", "")), tags$br(),
-        tags$b("sigmaPhi: "), res$sigmaphi, " &plusmn; ", res$sigmaphi_error, tags$em(ifelse(input$override_sigmaphi, "(fixed)", "")), tags$br(),
-        tags$b("mu: "), res$mu, " &plusmn; ", res$mu_error, tags$em(ifelse(input$override_mu, "\t(fixed)", "")), tags$br()
-      ))
+      HTML(
+          report("Age (a)", res$age, res$age_error, input$override_age),
+          report("sigmaPhi", res$sigmaphi, res$sigmaphi_error, input$override_sigmaphi),
+          report("mu", res$mu, res$mu_error, input$override_mu)
+      )
     } else {
       res <- as.data.frame(get_RLum(values$results))
 
-      HTML(paste0(
-        tags$b("Ages (a): "), paste(res$age, collapse = ", "), tags$em(" (fixed)"), tags$br(),
-        tags$b("sigmaPhi: "), signif(unique(res$sigmaphi), 3), " &plusmn; ", signif(unique(res$sigmaphi_error), 3), tags$em(ifelse(input$override_sigmaphi, "(fixed)", "")), tags$br(),
-        tags$b("mu: "), signif(unique(res$mu), 3), " &plusmn; ", signif(unique(res$mu_error), 3), tags$em(ifelse(input$override_mu, "\t(fixed)", "")), tags$br()
-      ))
+      HTML(
+        report("Ages (a)", res$age),
+        report("sigmaPhi", signif(unique(res$sigmaphi), 3),
+               signif(unique(res$sigmaphi_error), 3), input$override_sigmaphi),
+        report("mu", signif(unique(res$mu), 3),
+               signif(unique(res$mu_error), 3), input$override_mu)
+      )
     }
   })
 
-
 }##EndOf::function(input, output)
